@@ -1,7 +1,7 @@
 /*
  * libics: Image Cytometry Standard file reading and writing.
  *
- * Copyright 2015-2019, 2021, 2022, 2024:
+ * Copyright 2015-2019, 2021, 2022, 2024, 2025:
  *   Scientific Volume Imaging Holding B.V.
  *   Hilversum, The Netherlands.
  *   https://www.svi.nl
@@ -50,7 +50,7 @@ extern "C" {
 #endif
 
 /* Library versioning is in the form major, minor, patch: */
-#define ICSLIB_VERSION "1.6.8" /* also defined in configure.ac */
+#define ICSLIB_VERSION "1.7.0" /* also defined in configure.ac */
 
 #if defined(__WIN32__) && !defined(WIN32)
 #define WIN32
@@ -129,6 +129,8 @@ extern "C" {
 #define ICS_SENSOR_TYPE_NDCM          "NipkowConfMicr"
 /* This is a scanning SoRa disk confocal microscope: */
 #define ICS_SENSOR_TYPE_SORA          "SoRaConfMicr"
+/* This is an scanning Aurox disk confocal microscope: */
+#define ICS_SENSOR_TYPE_AUROX         "AuroxConfMicr"
 /* This is a STED microscope: */
 #define ICS_SENSOR_TYPE_STED          "STEDMicr"
 /* This is a Structured Illumination microscope: */
@@ -217,6 +219,7 @@ typedef enum {
     Ics_sint32,    /* integer, signed,   32 bpp */
     Ics_uint64,    /* integer, unsigned, 64 bpp */
     Ics_sint64,    /* integer, signed,   64 bpp */
+    Ics_real16,    /* real,    signed,   16 bpp */
     Ics_real32,    /* real,    signed,   32 bpp */
     Ics_real64,    /* real,    signed,   64 bpp */
     Ics_complex32, /* complex, signed, 2*32 bpp */
@@ -326,7 +329,9 @@ typedef enum {
     ICS_SENSOR_SCATTER_MODEL,
     ICS_SENSOR_SCATTER_FREE_PATH,
     ICS_SENSOR_SCATTER_REL_CONTRIB,
-    ICS_SENSOR_SCATTER_BLURRING,    
+    ICS_SENSOR_SCATTER_BLURRING,
+
+    ICS_SENSOR_SCALINGFACTOR,
     ICS_SENSOR_LAST
 } Ics_SensorParameter;
 
@@ -523,6 +528,9 @@ typedef struct _ICS {
         /* Scatter blurring: */
     double                  scatterBlurring[ICS_MAX_LAMBDA];
     Ics_SensorState         scatterBlurringState[ICS_MAX_LAMBDA];
+          /* Scaling factor applied to the data, per channel */
+    double                  scalingFactor[ICS_MAX_LAMBDA];
+    Ics_SensorState         scalingFactorState[ICS_MAX_LAMBDA];
 
         /* SCIL_Image compatibility parameter: */
     char                    scilType[ICS_STRLEN_TOKEN];
