@@ -1,7 +1,7 @@
 /*
  * libics: Image Cytometry Standard file reading and writing.
  *
- * Copyright 2015-2019:
+ * Copyright 2015-2019, 2025:
  *   Scientific Volume Imaging Holding B.V.
  *   Hilversum, The Netherlands.
  *   https://www.svi.nl
@@ -461,6 +461,9 @@ void IcsInit(Ics_Header *icsStruct)
         icsStruct->scatterRelContribState[i] = IcsSensorState_default;
         icsStruct->scatterBlurring[i] = 0.0;
         icsStruct->scatterBlurringState[i] = IcsSensorState_default;
+
+        icsStruct->scalingFactor[i] = 1.0;
+        icsStruct->scalingFactorState[i] = IcsSensorState_default;
     }
     icsStruct->scilType[0] = '\0';
 }
@@ -486,6 +489,7 @@ size_t IcsGetDataTypeSize(Ics_DataType dataType)
             break;
         case Ics_uint16:
         case Ics_sint16:
+        case Ics_real16:
             bytes = 2;
             break;
         case Ics_uint32:
@@ -531,6 +535,7 @@ void IcsGetPropsDataType(Ics_DataType  dataType,
         case Ics_sint64:
             *format = IcsForm_integer;
             break;
+        case Ics_real16:
         case Ics_real32:
         case Ics_real64:
             *format = IcsForm_real;
@@ -572,6 +577,9 @@ void IcsGetDataTypeProps(Ics_DataType* dataType,
             break;
         case IcsForm_real:
             switch (bits) {
+                case 16:
+                    *dataType = Ics_real16;
+                    break;
                 case 32:
                     *dataType = Ics_real32;
                     break;
