@@ -12,7 +12,11 @@ int main(int argc, const char* argv[]) {
    void*        buf1;
    void*        buf2;
    Ics_Error    retval;
-
+   double       origin;
+   double       scale;
+   const char*  units;
+   char         key[ICS_STRLEN_TOKEN];
+   char         value[ICS_LINE_LENGTH];
 
    if (argc != 2) {
       fprintf(stderr, "One file name required\n");
@@ -41,9 +45,9 @@ int main(int argc, const char* argv[]) {
    }
 
    /* Add and change metadata */
-   retval = IcsSetPosition(ip, 0, 1834, 0.02, "milimeter");
+   retval = IcsSetPosition(ip, 0, 1834, 0.02, "millimeter");
    if (retval == IcsErr_Ok)
-      retval = IcsSetPosition(ip, 1, -653, 0.014, "milimeter");
+      retval = IcsSetPosition(ip, 1, -653, 0.014, "mm");
    if (retval != IcsErr_Ok) {
       fprintf(stderr, "Could not set pixel position: %s\n",
               IcsGetErrorText(retval));
@@ -71,6 +75,39 @@ int main(int argc, const char* argv[]) {
               IcsGetErrorText(retval));
       exit(-1);
    }
+
+   /* Check metadata */
+   retval = IcsGetPositionF(ip, 0, &origin, &scale, &units);
+   if (retval == IcsErr_Ok) {
+      if (origin != 1834 || scale != 0.02 || strcmp(units, "millimeter") != 0 ) {
+         fprintf(stderr, "Different position metadata read back\n");
+         exit(-1);
+      }
+      retval = IcsGetPositionF(ip, 1, &origin, &scale, &units);
+      if (retval == IcsErr_Ok) {
+         if (origin != -653 || scale != 0.014 || strcmp(units, "mm") != 0) {
+            fprintf(stderr, "Different position metadata read back\n");
+            exit(-1);
+         }
+      }
+   }
+   if (retval != IcsErr_Ok) {
+      fprintf(stderr, "Could not get pixel position: %s\n",
+              IcsGetErrorText(retval));
+      exit(-1);
+   }
+   retval = IcsGetHistoryKeyValue(ip, key, value, IcsWhich_First);
+   if (retval != IcsErr_Ok) {
+      fprintf(stderr, "Could not get history key/value pair: %s\n",
+              IcsGetErrorText(retval));
+      exit(-1);
+   }
+   if (strcmp(key, "test") != 0 || strcmp(value, "Adding history line.") != 0) {
+      fprintf(stderr, "Different history key/value pair read back\n");
+      exit(-1);
+   }
+
+   /* Check pixel data */
    if (bufsize != IcsGetDataSize(ip)) {
       fprintf(stderr, "Data in output file not same size as input.\n");
       exit(-1);
